/*

RC Bruder Conversion Motorhalter

Soll an Bruder's großen Kettendozer (Cat D11T)

http://www.bruder.de/germany/sortiment/sortiment-und-serien/baufahrzeuge/?tx_sortiment_pi1%5Bartnr%5D=02452&tx_sortiment_pi1%5Baction%5D=details&tx_sortiment_pi1%5Bc%5D=1&direct=1
http://www.cat.com/en_US/products/new/equipment/dozers/large-dozers/18332635.html

Documentation to this design:

http://www.wurst-wasser.net/wiki/index.php?title=3D-Printed_Motor_Mount_for_Bruder_Cat_D11T_RC_Conversion
https://youtu.be/y7okxzaw5nU

*/

/* Modules */
include <../Modules/Module_Geometrical_Objects.scad>;

/* Globals */
//$fn=23;
$fn=50;
gMS=1.2;
gB=44+4.0;

/* Zierblende (zum Aufkleben) */
if (1)
translate([40, 0, 0])
difference()
{
	d1=27; //40;
	r2=11.5;
	d3=19;
	union()
		{
		cylinder(d=d1, h=3.0);
		for (a=[0:18*2:360])
		{
			rotate([0, 0, a])
			translate([r2, 0, 3.0])
			hexHub(3.0, 1.2);
		}
		cylinder(d=d3, h=10);
	}
cylinder(d=d3-2*2.0, h=100);
}

/* Der eigentliche Halter */
h1=10; // 10
//translate([0, 0, h1/2])
if (1)
difference()
{
	union()
	{
		h2=23;
		/* Oberes Parallelogramm */
		// https://en.wikibooks.org/wiki/OpenSCAD_User_Manual/Primitive_Solids#polyhedron
		CubePoints = [
			[  0,  0,  0 ],  //0
			[ gB,  0,  0 ],  //1
			[ gB-(gB-26)/2,  h2,  0 ],  //2
			[  +(gB-26)/2,  h2,  0 ],  //3
			[  0,  0,  h1 ],  //4
			[ gB,  0,  h1 ],  //5
			[ gB-(gB-26)/2,  h2,  h1 ],  //6
			[  +(gB-26)/2,  h2,  h1 ]]; //7
	  
		CubeFaces = [
			[0,1,2,3],  // bottom
			[4,5,1,0],  // front
			[7,6,5,4],  // top
			[5,6,2,1],  // right
			[6,7,3,2],  // back
			[7,4,0,3]]; // left
	  
		
		//rotate([0, 0, 180])
		translate([-gB/2, 15/2 , 0])
		polyhedron( CubePoints, CubeFaces);

		/* Mittelteil */
		translate([0, 0, h1/2])
		cube([gB, 15, h1], center=true);

		/* Unteres Parallelogramm */
		b1=24+6.0;
		// https://en.wikibooks.org/wiki/OpenSCAD_User_Manual/Primitive_Solids#polyhedron
		CubePoints2 = [
			[  0,  0,  0 ],  //0
			[ b1,  0,  0 ],  //1
			[ b1+(gB-b1)/2,  20,  0 ],  //2
			[  -(gB-b1)/2,  20,  0 ],  //3
			[  0,  0,  h1 ],  //4
			[ b1,  0,  h1 ],  //5
			[ b1+(gB-b1)/2,  20,  h1 ],  //6
			[  -(gB-b1)/2,  20,  h1 ]]; //7
	  
		CubeFaces2 = [
			[0,1,2,3],  // bottom
			[4,5,1,0],  // front
			[7,6,5,4],  // top
			[5,6,2,1],  // right
			[6,7,3,2],  // back
			[7,4,0,3]]; // left
	  
		translate([-b1/2, -20-15/2, -h1/2*0])
		polyhedron( CubePoints2, CubeFaces2);
	} // union
	cylinder(d=19-2*2.0, h=100); // Loch für Achse
	
	translate([0, -7, gMS]) // Achse ist 7mm versetzt von Motormitte
	cylinder(d=37.99, h=h1-gMS); // Aussparung für Planetengetriebe 
	
	translate([0, -7, 0])
	for (a2=[30:60:360])
	{
		rotate([0, 0, a2])
		translate([0, 32/2, 0])
		cylinder(d=3.0+1.0, h=100); // Verschraubung Planetengetriebe mit Halter
	}
	
	/* Löcher zur Verschraubung mit Chassis, oben */
	for (xi1=[-10, 10])
	translate([xi1, 25, 0])
	cylinder(d=3.0+1.0, h=100); // Aussparug für Planetengetriebe 

	/* Löcher zur Verschraubung mit Chassis, unten */
	for (xi1=[-13.5, 13.5])
	translate([xi1, -24.3, 0])
	cylinder(d=3.0+1.0, h=100); // Aussparug für Planetengetriebe 
	
	/* Aussparung oben */
	translate([0, 15/2+21.5, 2.0/2+h1-2.0])
	cube([22, 3, 2.0], center=true);
} // diff

















